Moogli
======

.. image:: https://travis-ci.org/aviralg/moogli.svg?branch=master
    :target: https://travis-ci.org/aviralg/moogli
    :alt: Build Status

.. image:: https://readthedocs.org/projects/moogli/badge/?version=latest
    :target: https://readthedocs.org/projects/moogli/?badge=latest
    :alt: Documentation Status

.. image:: https://d2weczhvl823v0.cloudfront.net/aviralg/moogli/trend.png
    :target: https://bitdeli.com/free
    :alt: Bitdeli Badge

Moogli is a 3D neuronal network activity visualizer. It can show neuronal network morphologies and visualize electrical and chemical activity from compartmental modeling simulations. It is platform agnostic and completely based on open source tools and libraries. Feel free to download, use and fork it.
